% Basic RBC Model
% + with consumption habits
% gauthier[at]vermandel.fr

close all;
%format long

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var y c h w r a g;
varexo e_a e_g;

parameters	beta alpha delta sigmaC sigmaL gy hc
			rho_a rho_g
			R Y C Z I
			;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

% Loading calibration
@#include "calibration.mod"

%----------------------------------------------------------------
% 3. Model (the number refers to the equation in the paper)
%----------------------------------------------------------------
model(linear);
    %% Household
	% Euler
	sigmaC*(c(+1)-(1+hc)*c+hc*c(-1))=r;
	% hours supply
	w = (1/sigmaL)*h + (sigmaC/(1-hc))*(c-hc*c(-1));
	
    % Intermediary firms
	% Production function
	y = a + (1-alpha)*h;
	% Inputs Cost minimization
	w = y - h;
    % Resources constraint
	y = (1-gy)*c + gy*g ;
		
    % Exogenous shocks
	a = rho_a*a(-1) + e_a;
	g = rho_g*g(-1) + e_g;
end;

%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------
check;
steady;


stoch_simul(order = 1,irf=30) y c w h r;